==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/inputs/AllowedPrincipalsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin.inputs

import com.pulumi.azurenative.web.inputs.AllowedPrincipalsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The configuration settings of the Azure Active Directory allowed principals.
 * @property groups The list of the allowed groups.
 * @property identities The list of the allowed identities.
 */
public data class AllowedPrincipalsArgs(
    public val groups: Output<List<String>>? = null,
    public val identities: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.web.inputs.AllowedPrincipalsArgs> {
    override fun toJava(): com.pulumi.azurenative.web.inputs.AllowedPrincipalsArgs =
        com.pulumi.azurenative.web.inputs.AllowedPrincipalsArgs.builder()
            .groups(groups?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .identities(identities?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [AllowedPrincipalsArgs].
 */
@PulumiTagMarker
public class AllowedPrincipalsArgsBuilder internal constructor() {
    private var groups: Output<List<String>>? = null

    private var identities: Output<List<String>>? = null

    /**
     * @param value The list of the allowed groups.
     */
    @JvmName("ergbxyaugmsidbvc")
    public suspend fun groups(`value`: Output<List<String>>) {
        this.groups = value
    }

    @JvmName("mrkrrddwbblqsadf")
    public suspend fun groups(vararg values: Output<String>) {
        this.groups = Output.all(values.asList())
    }

    /**
     * @param values The list of the allowed groups.
     */
    @JvmName("dlubqtltwomkxmdr")
    public suspend fun groups(values: List<Output<String>>) {
        this.groups = Output.all(values)
    }

    /**
     * @param value The list of the allowed identities.
     */
    @JvmName("cmakwhvvggskvgxe")
    public suspend fun identities(`value`: Output<List<String>>) {
        this.identities = value
    }

    @JvmName("ikgpnobcynboporl")
    public suspend fun identities(vararg values: Output<String>) {
        this.identities = Output.all(values.asList())
    }

    /**
     * @param values The list of the allowed identities.
     */
    @JvmName("qvlrhqiiwjkumloq")
    public suspend fun identities(values: List<Output<String>>) {
        this.identities = Output.all(values)
    }

    /**
     * @param value The list of the allowed groups.
     */
    @JvmName("dpkaipcnpdxvwfnf")
    public suspend fun groups(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.groups = mapped
    }

    /**
     * @param values The list of the allowed groups.
     */
    @JvmName("pwnkcepevhlaqknu")
    public suspend fun groups(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.groups = mapped
    }

    /**
     * @param value The list of the allowed identities.
     */
    @JvmName("xcykdiyiccykqqae")
    public suspend fun identities(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.identities = mapped
    }

    /**
     * @param values The list of the allowed identities.
     */
    @JvmName("iqlvionptlloynks")
    public suspend fun identities(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.identities = mapped
    }

    internal fun build(): AllowedPrincipalsArgs = AllowedPrincipalsArgs(
        groups = groups,
        identities = identities,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/inputs/AllowedPrincipalsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin.inputs

import com.pulumi.azurenative.web.inputs.AllowedPrincipalsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The configuration settings of the Azure Active Directory allowed principals.
 * @property groups The list of the allowed groups.
 * @property identities The list of the allowed identities.
 */
public data class AllowedPrincipalsArgs(
    public val groups: Output<List<String>>? = null,
    public val identities: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.web.inputs.AllowedPrincipalsArgs> {
    override fun toJava(): com.pulumi.azurenative.web.inputs.AllowedPrincipalsArgs =
        com.pulumi.azurenative.web.inputs.AllowedPrincipalsArgs.builder()
            .groups(groups?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .identities(identities?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [AllowedPrincipalsArgs].
 */
@PulumiTagMarker
public class AllowedPrincipalsArgsBuilder internal constructor() {
    private var groups: Output<List<String>>? = null

    private var identities: Output<List<String>>? = null

    /**
     * @param value The list of the allowed groups.
     */
    @JvmName("iqeqscrylsuvnwxf")
    public suspend fun groups(`value`: Output<List<String>>) {
        this.groups = value
    }

    @JvmName("afpdfqfgcrspqvqh")
    public suspend fun groups(vararg values: Output<String>) {
        this.groups = Output.all(values.asList())
    }

    /**
     * @param values The list of the allowed groups.
     */
    @JvmName("vafoyyjacopsojfv")
    public suspend fun groups(values: List<Output<String>>) {
        this.groups = Output.all(values)
    }

    /**
     * @param value The list of the allowed identities.
     */
    @JvmName("wfnbbglegbxutbus")
    public suspend fun identities(`value`: Output<List<String>>) {
        this.identities = value
    }

    @JvmName("bjabkrfplmwhyysq")
    public suspend fun identities(vararg values: Output<String>) {
        this.identities = Output.all(values.asList())
    }

    /**
     * @param values The list of the allowed identities.
     */
    @JvmName("nhhiiirdweevskdr")
    public suspend fun identities(values: List<Output<String>>) {
        this.identities = Output.all(values)
    }

    /**
     * @param value The list of the allowed groups.
     */
    @JvmName("bkcayxtwvirksxsg")
    public suspend fun groups(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.groups = mapped
    }

    /**
     * @param values The list of the allowed groups.
     */
    @JvmName("yqrechtbfavgyyhs")
    public suspend fun groups(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.groups = mapped
    }

    /**
     * @param value The list of the allowed identities.
     */
    @JvmName("raitjyvaccxpetfy")
    public suspend fun identities(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.identities = mapped
    }

    /**
     * @param values The list of the allowed identities.
     */
    @JvmName("toxjanvoxcxkhgta")
    public suspend fun identities(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.identities = mapped
    }

    internal fun build(): AllowedPrincipalsArgs = AllowedPrincipalsArgs(
        groups = groups,
        identities = identities,
    )
}
